# 📖 Summary
- [📖 Summary](#-summary)
- [💼 About Jobology](#-about-jobology)
  - [😍 Why is it a big deal for Jobology customers & partners?](#-why-is-it-a-big-deal-for-jobology-customers--partners)
- [🔧 How does it work?](#-how-does-it-work)
  - [📊 Data integration capabilities:](#-data-integration-capabilities)
- [🔌 Connector Actions](#-connector-actions)
- [💍 Quick Start Examples](#-quick-start-examples)
- [🔗 Useful Links](#-useful-links)
- [👏 Special Thanks](#-special-thanks)


# 💼 About Jobology

> La mission de jobology est de faciliter le processus de recrutement pour les entreprises 


## 😍 Why is it a big deal for Jobology customers & partners?

This new connector will enable:
- ⚡ A Fastlane Talent & Workforce data integration for Jobology customers & partners
- 🤖 Cutting-edge AI-powered Talent Experiences & Recruiter Experiences for Jobology customers

#  🔧 How does it work?
## 📊 Data integration capabilities:
- ⬅️ Send Profiles data from Jobology to a Destination of your choice:





# 🔌 Connector Actions
<p align="center">

| Action | Description |
| ------- | ----------- |
| [**Catch profile**](docs/catch_profile.md) | Imports candidates, in synchronization with jobology |


</p>

<p align="center">
<image src=https://github.com/Riminder/hrflow-connectors/assets/135601200/1d28d312-6c28-4749-a5f1-b72fa8c16730 width=90% height=100% >
</p>


# 💍 Quick Start Examples

To make sure you can successfully run the latest versions of the example scripts, you have to **install the package from PyPi**.


To browse the examples of actions corresponding to released versions of 🤗 this connector, you just need to import the module like this :

<p align="center">
<image src=https://github.com/Riminder/hrflow-connectors/assets/135601200/1f295bdc-b505-4e5c-9d2f-0163844a2da8 width=90% height=100% >
</p>


Once the connector module is imported, you can leverage all the different actions that it offers.

For more code details checkout connector code.


# 🔗 Useful Links

- 📄Visit [Jobology](https://www.jobology.com/) to learn more.
- 💻 [Connector code](https://github.com/Riminder/hrflow-connectors/tree/master/src/hrflow_connectors/connectors/jobology) on our Github.


# 👏 Special Thanks
- 💻 HrFlow.ai : Abdellahi Mezid - Software Engineer
- 🤝 Jobology : Jobology Team